/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/


#ifndef INTERFACEPERSISTENCE_H
#define INTERFACEPERSISTENCE_H


#include <QVariant>

/**
 * Interface for all objects that should be serialized by the PersistenceManager
*/
class InterfacePersistence {
public:
    /**
     * Convert all data from the object to a QVariant (usually a QVariantMap)
    */
    virtual QVariant toVariant() const = 0;
    /**
     * Load data from a QVariant to initialize the current object
    */
    virtual void fromVariant(const QVariant&) = 0;

    /**
     * Get the universally unique ID of the object to be saved
    */
    // virtual QUuid getUuid() = 0; TODO
    /**
     * Set the universally unique ID of the object to be saved
     * @param id The value of the UUID to set. If you don't set this parameter, it will set a random UUID.
     * @warning DO NOT change the UUID of an object, set it only if it is null
     * @return If the current Uuid is not null, this returns false and does not modify the object
    */
    // virtual bool setUuid(QUuid id = QUuid()) = 0; TODO
};

#endif //INTERFACEPERSISTENCE_H
